from setuptools import setup, find_packages

setup(
    name="kurumii",
    version=1.2,
    packages=find_packages(),
    author="Nico",
    description="A handy litle tool",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown"
)


from .ascii import print_ascii,ascii_art,ascii_art_colored,print_ascii_colored
from .print_additions import nice_print,print_warning,print_colored,print_debug,print_header,print_bold,print_danger,print_green,print_info,print_italic,print_red,print_strikethrough,print_success,print_system,print_underline
from .id import generateId,generateTextId,splitStringAt50Percent
from .jsonify import addJson,backupJson,createJson,deleteJson,deleteJsonData,editJson,loadJson,loadJsonData,overwriteJson,sortJsonFile,validateJson,renameJson
from .additional_functions import camel_to_snake,deep_copy,factorial,flatten_list,is_prime,is_valid_date,is_valid_email,log_error,log_info,log_warning,merge_dicts,read_csv,remove_whitespace,retry_func,reverse_list,timer,write_to_file,unique_elements,truncate_string
from .keyboard import get_keypress,get_pressed_keys_list,is_key_pressed,wait_for_any_keypress,wait_for_keypress